Functions
=========

Daft Functions provide a set of built-in operations that can be applied to DataFrame columns.

This page provides an overview of all the functions provided by Daft.

.. currentmodule:: daft.functions

Sequence Functions
##################

.. autosummary::
   :nosignatures:
   :toctree: doc_gen/function_methods

   monotonically_increasing_id
   llm_generate
   columns_sum
   columns_mean
   columns_avg
   columns_min
   columns_max
